@@ -2,7 +2,8 @@ import datetime
 import inspect
 import mimetypes
 import sys
-from os import getcwd
+from os import getcwd, unlink
+from platform import system
 from tempfile import NamedTemporaryFile
 from typing import Any, Callable, Dict, List, Type
 
@@ -36,18 +37,29 @@ def launch_ui(opyrator_path: str, port: int = 8501) -> None:
     # import streamlit.bootstrap as bootstrap
     # from streamlit.cli import _get_command_line_as_string
     # print(_get_command_line_as_string())
-    with NamedTemporaryFile(suffix=".py", mode="w", encoding="utf-8") as f:
+
+    # Use delete=False and manually delete the file because otherwise it will show a 'Permission denied' error on Windows
+    with NamedTemporaryFile(
+        suffix=".py", mode="w", encoding="utf-8", delete=False
+    ) as f:
         f.write(STREAMLIT_RUNNER_SNIPPET.format(opyrator_path=opyrator_path))
         f.seek(0)
 
         # TODO: PYTHONPATH="$PYTHONPATH:/workspace/opyrator/src"
         import subprocess
 
+        python_path = f'PYTHONPATH="$PYTHONPATH:{getcwd()}"'
+        if system() == "Windows":
+            python_path = f"set PYTHONPATH=%PYTHONPATH%;{getcwd()} &&"
+
         subprocess.run(
-            f'PYTHONPATH="$PYTHONPATH:{getcwd()}" {sys.executable} -m streamlit run --server.port={port} --server.headless=True --runner.magicEnabled=False --server.maxUploadSize=50 --browser.gatherUsageStats=False {f.name}',
+            f"{python_path} {sys.executable} -m streamlit run --server.port={port} --server.headless=True --runner.magicEnabled=False --server.maxUploadSize=50 --browser.gatherUsageStats=False {f.name}",
             shell=True,
         )
 
+        f.close()
+        unlink(f.name)
+
 
 def function_has_named_arg(func: Callable, parameter: str) -> bool:
     try:
